@@ -175,13 +175,24 @@ class Storage:
         if 'fki_record_id' in data:
             self.fki_record_id = data['fki_record_id']
 
+
 class Device:
     def __init__(self):
         self.uuid = None
+        self.vchar_serial = None
+        self.vchar_model = None
+        self.fki_project_id = None
 
     def from_json(self, data):
         if 'uuid' in data:
             self.uuid = data['uuid']
+        if 'vchar_serial' in data:
+            self.vchar_serial = data['vchar_serial']
+        if 'vchar_model' in data:
+            self.vchar_model = data['vchar_model']
+        if 'fki_project_id' in data:
+            self.fki_project_id = data['fki_project_id']
+
 
 class FramesManager:
     def __init__(self):
